local revision = tonumber(string.sub("$Revision: 19799 $", 12, -3))
if revision > Cartographer.revision then
	Cartographer.version = "r" .. revision
	Cartographer.revision = revision
	Cartographer.date = string.sub("$Date: 2006-12-09 23:03:58 -0500 (Sat, 09 Dec 2006) $", 8, 17)
end

local L = AceLibrary("AceLocale-2.2"):new("Cartographer-Coordinates")

L:RegisterTranslations("enUS", function() return {
	["Coordinates"] = true,
	["Module to add coordinates to the bottom of the world map of the player and the cursor."] = true,
	
	["Cursor"] = true,
	["Player"] = true,
	
	["Background color"] = true,
	["The color of the background frame behind coordinates"] = true,
	
	["Text color"] = true,
	["The color of the coordinates"] = true,
	
	["Text size"] = true,
	["The size of the coordinates"] = true,
	
	["Show background"] = true,
	["Show background frame behind coordinates"] = true,
} end)

L:RegisterTranslations("deDE", function() return {
--	["Coordinates"] = true,
--	["Module to add coordinates to the bottom of the world map of the player and the cursor."] = true,
	
	["Cursor"] = "Cursor",
	["Player"] = "Spieler",
	
--	["Background color"] = true,
--	["The color of the background frame behind coordinates"] = true,
	
--	["Text color"] = true,
--	["The color of the coordinates"] = true,
	
--	["Text size"] = true,
--	["The size of the coordinates"] = true,
	
--	["Show background"] = true,
--	["Show background frame behind coordinates"] = true,
} end)

L:RegisterTranslations("frFR", function() return {
--	["Coordinates"] = true,
--	["Module to add coordinates to the bottom of the world map of the player and the cursor."] = true,
	
	["Cursor"] = "Curseur",
	["Player"] = "Joueur",
	
--	["Background color"] = true,
--	["The color of the background frame behind coordinates"] = true,
	
--	["Text color"] = true,
--	["The color of the coordinates"] = true,
	
--	["Text size"] = true,
--	["The size of the coordinates"] = true,
	
--	["Show background"] = true,
--	["Show background frame behind coordinates"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Coordinates"] = "좌표",
	["Module to add coordinates to the bottom of the world map of the player and the cursor."] = "플레이어와 커서의 좌표를 세계 지도 밑에 보여줍니다.",
	
	["Cursor"] = "커서",
	["Player"] = "플레이어",
	
--	["Background color"] = true,
--	["The color of the background frame behind coordinates"] = true,
	
--	["Text color"] = true,
--	["The color of the coordinates"] = true,
	
--	["Text size"] = true,
--	["The size of the coordinates"] = true,
	
--	["Show background"] = true,
--	["Show background frame behind coordinates"] = true,
} end)

L:RegisterTranslations("zhTW", function() return {
--	["Coordinates"] = true,
--	["Module to add coordinates to the bottom of the world map of the player and the cursor."] = true,
	
	["Cursor"] = "指標",
	["Player"] = "玩家",
	
--	["Background color"] = true,
--	["The color of the background frame behind coordinates"] = true,
	
--	["Text color"] = true,
--	["The color of the coordinates"] = true,
	
--	["Text size"] = true,
--	["The size of the coordinates"] = true,
	
--	["Show background"] = true,
--	["Show background frame behind coordinates"] = true,
} end)

Cartographer_Coordinates = Cartographer:NewModule("Coordinates")

function Cartographer_Coordinates:OnInitialize()
	self.db = Cartographer:AcquireDBNamespace("Coordinates")
	Cartographer:RegisterDefaults("Coordinates", "profile", {
		background = false,
		backgroundR = 0,
		backgroundG = 0,
		backgroundB = 0,
		backgroundA = 1,
		textR = 1,
		textG = 0.82,
		textB = 0,
		textA = 1,
		textSize = 1,
	})

	Cartographer.options.args.Coordinates = {
		name = L["Coordinates"],
		desc = L["Module to add coordinates to the bottom of the world map of the player and the cursor."],
		type = 'group',
		args = {
			bgColor = {
				name = L["Background color"],
				desc = L["The color of the background frame behind coordinates"],
				type = "color",
				get = "GetBackgroundColor",
				set = "SetBackgroundColor",
				hasAlpha = true,
				disabled = function() return not self:IsShowingBackground() end
			},
			color = {
				name = L["Text color"],
				desc = L["The color of the coordinates"],
				type = "color",
				get = "GetTextColor",
				set = "SetTextColor",
				hasAlpha = true,
			},
			size = {
				name = L["Text size"],
				desc = L["The size of the coordinates"],
				type = "range",
				get = "GetTextSize",
				set = "SetTextSize",
				min = 0.5,
				max = 1.5,
				isPercent = true,
				step = 0.05
			},
			background = {
				name = L["Show background"],
				desc = L["Show background frame behind coordinates"],
				type = "toggle",
				get = "IsShowingBackground",
				set = "ToggleShowingBackground",
			},
			toggle = {
				name = AceLibrary("AceLocale-2.2"):new("Cartographer")["Enabled"],
				desc = AceLibrary("AceLocale-2.2"):new("Cartographer")["Suspend/resume this module."],
				type = "toggle",
				order = -1,
				get = function() return Cartographer:IsModuleActive(self) end,
				set = function() Cartographer:ToggleModuleActive(self) end
			},
		},
		handler = self,
	}
	
end

function Cartographer_Coordinates:OnEnable()
	if not self.frame then
		self.frame = CreateFrame("Frame", "CartographerCoordinates", WorldMapFrame)
		self.frame:SetScript("OnUpdate", self.OnUpdate)
		
		self.frame.cursorCoords = self.frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		self.frame.cursorCoords:SetPoint("RIGHT", WorldMapFrame, "CENTER", -80, -367)
		self.frame.cursorCoords:SetTextColor(self:GetTextColor())
		local font,_,style = self.frame.cursorCoords:GetFont()
		self.frame.cursorCoords:SetFont(font,self:GetTextSize()*12,style)
		
		self.frame.playerCoords = self.frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
		self.frame.playerCoords:SetPoint("LEFT", WorldMapFrame, "CENTER", 80, -367)
		self.frame.playerCoords:SetTextColor(self:GetTextColor())
		local font,_,style = self.frame.playerCoords:GetFont()
		self.frame.playerCoords:SetFont(font,self:GetTextSize()*12,style)
		
		self.background1 = CreateFrame("Frame", "CartographerCoordinatesBackground1", WorldMapFrame)
		self.background1:SetPoint("TOPLEFT", self.frame.cursorCoords, "TOPLEFT", -3, 3)
		self.background1:SetPoint("BOTTOMRIGHT", self.frame.cursorCoords, "BOTTOMRIGHT", 3, -3)
		local tex = self.background1:CreateTexture()
		self.background1.texture = tex
		tex:SetAllPoints(self.background1)
		tex:SetTexture(self:GetBackgroundColor())
		
		self.background2 = CreateFrame("Frame", "CartographerCoordinatesBackground2", WorldMapFrame)
		self.background2:SetPoint("TOPLEFT", self.frame.playerCoords, "TOPLEFT", -3, 3)
		self.background2:SetPoint("BOTTOMRIGHT", self.frame.playerCoords, "BOTTOMRIGHT", 3, -3)
		local tex = self.background2:CreateTexture()
		self.background2.texture = tex
		tex:SetAllPoints(self.background2)
		tex:SetTexture(self:GetBackgroundColor())
	end
	if not self.db.profile.background then
		self.background1:Hide()
		self.background2:Hide()
	else
		self.background1:Show()
		self.background2:Show()
	end
	self.frame:Show()
end

function Cartographer_Coordinates:OnDisable()
	self.frame:Hide()
	self.background1:Hide()
	self.background2:Hide()
end

function Cartographer_Coordinates.OnUpdate()
	local self = Cartographer_Coordinates
	local x, y = GetCursorPosition()
	
	local px, py = GetPlayerMapPosition("player")
	local left, top = WorldMapDetailFrame:GetLeft(), WorldMapDetailFrame:GetTop()
	local width = WorldMapDetailFrame:GetWidth()
	local height = WorldMapDetailFrame:GetHeight()
	local scale = WorldMapDetailFrame:GetEffectiveScale()
	local cx = (x/scale - left) / width
	local cy = (top - y/scale) / height
	
	self.frame.cursorCoords:SetText(string.format("%s: %.1f, %.1f", L["Cursor"], 100 * cx, 100 * cy))
	if px == 0 or py == 0 or IsInInstance() or Cartographer:GetCurrentInstance() then
		self.frame.playerCoords:SetText("")
	else
		self.frame.playerCoords:SetText(string.format("%s: %.1f, %.1f", L["Player"], 100 * px, 100 * py))
	end
end

function Cartographer_Coordinates:IsShowingBackground()
	return self.db.profile.background
end

function Cartographer_Coordinates:ToggleShowingBackground(value)
	if value == nil then
		value = not self.db.profile.background
	end
	self.db.profile.background = value
	
	if not value then
		self.background1:Hide()
		self.background2:Hide()
	else
		self.background1:Show()
		self.background2:Show()
	end
end

function Cartographer_Coordinates:GetBackgroundColor()
	return self.db.profile.backgroundR, self.db.profile.backgroundG, self.db.profile.backgroundB, self.db.profile.backgroundA
end

function Cartographer_Coordinates:SetBackgroundColor(r, g, b, a)
	self.db.profile.backgroundR, self.db.profile.backgroundG, self.db.profile.backgroundB, self.db.profile.backgroundA = r, g, b, a
	
	self.background1.texture:SetTexture(r, g, b, a)
	self.background2.texture:SetTexture(r, g, b, a)
end

function Cartographer_Coordinates:GetTextColor()
	return self.db.profile.textR, self.db.profile.textG, self.db.profile.textB, self.db.profile.textA
end

function Cartographer_Coordinates:SetTextColor(r, g, b, a)
	self.db.profile.textR, self.db.profile.textG, self.db.profile.textB, self.db.profile.textA = r, g, b, a
	
	self.frame.cursorCoords:SetTextColor(r, g, b, a)
	self.frame.playerCoords:SetTextColor(r, g, b, a)
end

function Cartographer_Coordinates:GetTextSize()
	return self.db.profile.textSize
end

function Cartographer_Coordinates:SetTextSize(value)
	self.db.profile.textSize = value
	
	local font,_,style = self.frame.cursorCoords:GetFont()
	self.frame.cursorCoords:SetFont(font,value*12,style)
	local font,_,style = self.frame.playerCoords:GetFont()
	self.frame.playerCoords:SetFont(font,value*12,style)
end
